(function() {
  var ApiMapper, CircleCI, q, qreq;

  qreq = require("qreq");

  ApiMapper = require("./api-mapper");

  q = require("q");

  CircleCI = (function() {
    CircleCI.init = function(config) {
      return new CircleCI(config);
    };

    function CircleCI(config) {
      if (!config.apiToken) {
        throw new Error("API Token required");
      }
      this.mapper = new ApiMapper(config);
    }

    CircleCI.prototype.makeRequest = function(fn, opts, callback) {
      var deferred;
      if (opts == null) {
        opts = {};
      }
      if (callback == null) {
        callback = null;
      }
      deferred = q.defer();
      if (typeof opts === 'function') {
        callback = opts;
        opts = {};
      }
      this.mapper.getRequestObject(fn, opts).then(function(res) {
        deferred.resolve(res.body);
        if (callback) {
          return callback(null, res.body);
        }
      }).fail(function(err) {
        deferred.reject(err);
        if (callback) {
          return callback(err);
        }
      });
      return deferred.promise;
    };

    CircleCI.prototype.getUser = function(callback) {
      return this.makeRequest("getUser", callback);
    };

    CircleCI.prototype.getRecentProjects = function(config, callback) {
      return this.makeRequest("getRecentProjects", config, callback);
    };

    CircleCI.prototype.getProject = function(config, callback) {
      return this.makeRequest("getProject", config, callback);
    };

    CircleCI.prototype.getRecentBuilds = function(config, callback) {
      return this.makeRequest("getRecentBuilds", config, callback);
    };

    CircleCI.prototype.getBuild = function(config, callback) {
      return this.makeRequest("getBuild", config, callback);
    };

    CircleCI.prototype.startBuild = function(config, callback) {
      return this.makeRequest("startBuild", config, callback);
    };

    CircleCI.prototype.cancelBuild = function(config, callback) {
      return this.makeRequest("cancelBuild", config, callback);
    };

    CircleCI.prototype.retryBuild = function(config, callback) {
      return this.makeRequest("retryBuild", config, callback);
    };

    CircleCI.prototype.getBuildArtifacts = function(config, callback) {
      return this.makeRequest("getBuildArtifacts", config, callback);
    };

    CircleCI.prototype.clearBuildCache = function(config, callback) {
      return this.makeRequest("clearBuildCache", config, callback);
    };

    return CircleCI;

  })();

  module.exports = CircleCI;

}).call(this);
