(function() {
  var UrlGenerator, qs;

  qs = require("querystring");

  UrlGenerator = (function() {
    function UrlGenerator(config) {
      if (config == null) {
        config = {};
      }
      this.host = config.host || "https://circleci.com";
      this.version = config.version || "v1";
      this.apiToken = config.apiToken;
    }

    UrlGenerator.prototype.getBaseUrl = function() {
      return "" + this.host + "/api/" + this.version;
    };

    UrlGenerator.prototype.getQueryString = function(params) {
      var paramString, queryString;
      if (params == null) {
        params = {};
      }
      paramString = qs.stringify(params);
      queryString = "?circleci_token=" + this.apiToken;
      if (paramString) {
        queryString += "&" + paramString;
      }
      return queryString;
    };

    UrlGenerator.prototype.injectParams = function(path, params, identifier) {
      var fragment, fragments, i, paramKey, paramValue, regexp, _i, _len;
      if (params == null) {
        params = {};
      }
      if (identifier == null) {
        identifier = ":";
      }
      fragments = path.split("/");
      for (i = _i = 0, _len = fragments.length; _i < _len; i = ++_i) {
        fragment = fragments[i];
        for (paramKey in params) {
          paramValue = params[paramKey];
          regexp = new RegExp("^:" + paramKey + "$");
          if (fragment.match(regexp)) {
            fragments[i] = fragment.replace(regexp, paramValue);
          }
        }
      }
      return fragments.join("/");
    };

    UrlGenerator.prototype.getUrl = function(path, config) {
      var url;
      if (path == null) {
        path = "";
      }
      if (config == null) {
        config = {};
      }
      url = this.getBaseUrl();
      if (path) {
        url += "/" + this.injectParams(path.replace(/^\//, ""), config.params);
      }
      url += this.getQueryString(config.query);
      return url;
    };

    return UrlGenerator;

  })();

  module.exports = UrlGenerator;

}).call(this);
